\name{Schaake.Shuffle}
\title{Shuffling of time series elements through Schaake Shuffle}
\usage{
Schaake.Shuffle(refseries, seriestoshuffle)
}
\alias{Schaake.Shuffle}
\description{Shuffles the vector "seriestoshuffle" (i.e., the time series to be shuffled) to reconstruct the temporal structure based on the vector "refseries" containing the time series of reference.
The two vectors "refseries" and "seriestoshuffle" must have the same length.
}
\arguments{
  \item{refseries}{Vector containing the time series of reference.}
  \item{seriestoshuffle}{Vector time series to be shuffled to reconstruct the temporal structure of the time series of reference.}
}
\value{Returns a vector corresponding to the shuffling of "seriestoshuffle".
}
\details{For details on the mathematical formulation, see the reference below.

Vrac, M. and Friederichs, P. (2014), Multivariate - Inter-variable, spatial and temporal - bias correction. In revision.
}
\author{M. Vrac (mathieu.vrac@lsce.ipsl.fr) and P. Friederichs (pfried@uni-bonn.de)}
\seealso{\code{\link{ECBC}}}
\examples{
## Example

### Generation of example data
refseries <- rnorm(100,mean=0,sd=1)
seriestoshuffle <- rnorm(100,mean=0,sd=1)

### Call of the Schaake.Shuffle method
ShuffledSeries = Schaake.Shuffle(refseries, seriestoshuffle)

### Plot the results
YL=range(refseries, seriestoshuffle, ShuffledSeries)
YL[2] = YL[2]+2
plot(c(1:100), ShuffledSeries,type="l",lty=2, col=2, ylim=YL, xlab="(e.g.) time", ylab="series")
lines(c(1:100),refseries,type="l",lty=1,col=2)
lines(c(1:100),seriestoshuffle,type="l", lty=1, col=1)

legend(x=1,y=5.0, "refseries", lty=1, col=2, bty="n")
legend(x=1,y=4.5, "seriestoshuffle", lty=1, col=1, bty="n")
legend(x=1,y=4, "ShuffledSeries", lty=2, col=2, bty="n")

}
\keyword{math}
\keyword{ts}
\keyword{nonparametric}
\keyword{models}
